#!/bin/sh
set -x

#####
#	this adds wavenumebr integration solutions
#	and is careful to correctly update the current W.WCL
#####



#####
#	shell script for creating the eigenfunction
#	Green s function files for source inversion
#####

#####
#	define the DESTINATION DIRECTORY
#	
#	PATH is high level path which must exist
#	MODEL is the model directory which will be created if required
#	PMIN, PMAX are the periods for which eigenfunctions are
#		to be created
#
#####

DEST=${GREENDIR}
#####
#       Since this script is already in the directory
#       redefine the DEST to
#
#####
MODEL=WUS.REG
PMIN=1.0
PMAX=100.0
Mname=WUS.mod

if [ ! -d ${DEST}/${MODEL} ]
then
	echo Creating the Directory ${DEST}/${MODEL}
	mkdir ${DEST}/${MODEL}
fi

#####
#	create the model subdirectory
#####

if [ ! -d ${DEST}/${MODEL}/Model ]
then
	echo Creating the Directory ${DEST}/${MODEL}/Model
	mkdir ${DEST}/${MODEL}/Model
fi

#####
#	create the surface-wave control directory
#####

if [ ! -d ${DEST}/${MODEL}/SW ]
then
	echo Creating the Directory ${DEST}/${MODEL}/SW
	mkdir ${DEST}/${MODEL}/SW
fi

#####
#	define the earth model here - the many layers permit the
#	specification of eigenfunctions with depth - should
#	rewrite slegn96 and regn96 to permit layer insertion
#	this way the simple model can be used to get disperion curves
#
#	ham96.mod is the simple model for for wavenumber integration
#	dham96.mod is the detailed model for eigenfunctions
#####

cp ${Mname} ${DEST}/${MODEL}/Model/${Mname}
cp d${Mname} ${DEST}/${MODEL}/Model/d${Mname}

#####
#	go to the working directory
#####

cd ${DEST}/${MODEL}/SW

#####
#	create the surface wave data sets
#####

sprep96 -PMIN ${PMIN} -PMAX ${PMAX} -M ../Model/d${Mname} -L -R -NMOD 1
sdisp96 
sregn96 -DER 
slegn96 -DER 

######
#       Uncomment this if you want to see the eigenfunctions
#####
sdpder96 -L -TXT
sdpder96 -R -TXT
#####
#       create the eigenfunction for dispersion
#####
sprep96 -PMIN ${PMIN} -PMAX ${PMAX} -M ../Model/d${Mname} -L -R -NMOD 1
sdisp96
sregn96
slegn96

